package com.xirihanlin.earthquake;

import java.io.IOException;
import java.io.InputStream;
import java.net.HttpURLConnection;
import java.net.MalformedURLException;
import java.net.URL;
import java.net.URLConnection;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.GregorianCalendar;

import javax.xml.parsers.DocumentBuilder;
import javax.xml.parsers.DocumentBuilderFactory;
import javax.xml.parsers.ParserConfigurationException;

import org.w3c.dom.Document;
import org.w3c.dom.Element;
import org.w3c.dom.NodeList;
import org.xml.sax.SAXException;

import android.app.Activity;
import android.app.AlertDialog;
import android.app.Dialog;
import android.location.Location;
import android.os.Bundle;
import android.view.LayoutInflater;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.widget.AdapterView;
import android.widget.ArrayAdapter;
import android.widget.ListView;
import android.widget.TextView;
import android.widget.AdapterView.OnItemClickListener;

public class Earthquake extends Activity {
	ListView earthquakeListView;
	ArrayAdapter<Quake> aa;
	ArrayList<Quake> earthquakes = new ArrayList<Quake>();
	Quake seletedQuake;
	
	static final private int MENU_UPDATE = Menu.FIRST;
	static final private int QUAKE_DIALOG = 1;
	
    /** Called when the activity is first created. */
    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.main);
        
        earthquakeListView = (ListView)findViewById(R.id.earthquakeListView);
        earthquakeListView.setOnItemClickListener(new OnItemClickListener()
        {
			@Override
			public void onItemClick(AdapterView<?> arg0, View arg1, int arg2, long arg3) {
				seletedQuake = earthquakes.get(arg2);
				showDialog(QUAKE_DIALOG);
			}
        }
        );
        aa = new ArrayAdapter<Quake>(this, android.R.layout.simple_list_item_1, earthquakes);
        earthquakeListView.setAdapter(aa);
        refreshEarthquakes();
    }
    
    @Override
	public boolean onCreateOptionsMenu(Menu menu) {
		super.onCreateOptionsMenu(menu);
		menu.add(0, MENU_UPDATE, Menu.NONE, R.string.menu_update);
		return true;
	}

	@Override
	public boolean onOptionsItemSelected(MenuItem item) {
		super.onOptionsItemSelected(item);
		switch (item.getItemId()) {
		case MENU_UPDATE:
		{
			refreshEarthquakes();
			return true;
		}
		}
		return false;
	}

	@Override
	protected Dialog onCreateDialog(int id) {
		switch (id) {
		case QUAKE_DIALOG:
		{
			LayoutInflater li = LayoutInflater.from(this);
			View quakeDetailView = li.inflate(R.layout.quake_detail, null);
			AlertDialog.Builder dialog = new AlertDialog.Builder(this);
			dialog.setTitle("Quake Time");
			dialog.setView(quakeDetailView);
			return dialog.create();
		}
		}
		return null;
	}

	@Override
	protected void onPrepareDialog(int id, Dialog dialog) {
		switch (id) {
		case QUAKE_DIALOG:
			SimpleDateFormat sdf;
			sdf = new SimpleDateFormat("dd/MM/yyyy HH:mm:ss");
			String dateString =	sdf.format(seletedQuake.getDate());
			String quakeText = "Magnitude " + seletedQuake.getMagnitude() + "\n"
				+ seletedQuake.getDetail() + "\n"
				+ seletedQuake.getLink();
			AlertDialog quakeDialog = (AlertDialog)dialog;
			quakeDialog.setTitle(dateString);
			TextView tv = (TextView)quakeDialog.findViewById(R.id.earthquakeTextView);
			tv.setText(quakeText);
			break;
		}
	}

	private void refreshEarthquakes() {
		//URL url;
		try 
		{
			//String quakeFeed = getString(R.string.quake_feed);
			//url = new URL(quakeFeed);
			//URLConnection connection;
			//connection = url.openConnection();
			//HttpURLConnection httpURLConnection = (HttpURLConnection)connection;
			//int responseCode = httpURLConnection.getResponseCode();
			//if (responseCode == HttpURLConnection.HTTP_OK) 
			{
				//InputStream in = httpURLConnection.getInputStream();
			}
			{
				InputStream in = getResources().openRawResource(R.raw.xx);
				DocumentBuilderFactory dbf;
				dbf = DocumentBuilderFactory.newInstance();
				DocumentBuilder db = dbf.newDocumentBuilder();
				Document doc = db.parse(in);
				
				Element docElement = doc.getDocumentElement();
				earthquakes.clear();
				NodeList nl = docElement.getElementsByTagName("entry");
				if (nl != null && nl.getLength() > 0) 
				{
					for (int i = 0; i < nl.getLength(); i++)
					{
						Element entry = (Element)nl.item(i);
						Element title = (Element)entry.getElementsByTagName("title").item(0);
						Element g = (Element)entry.getElementsByTagName("georss:point").item(0);
						Element when = (Element)entry.getElementsByTagName("updated").item(0);
						Element linkE = (Element)entry.getElementsByTagName("link").item(0);
						String detail = title.getFirstChild().getNodeValue();
						String hostname = "http://earthquake.usgs.gov";
						String link = hostname + linkE.getAttribute("href");
						String pointString = g.getFirstChild().getNodeValue();
						String dt = when.getFirstChild().getNodeValue();
						
						SimpleDateFormat sdf;
						sdf = new SimpleDateFormat("yyyy-MM-dd'T'HH:mm:ss'Z'");
						Date qDate = new GregorianCalendar(0, 0, 0).getTime();
						try 
						{
							qDate = sdf.parse(dt);
						} 
						catch (ParseException e) 
						{
							e.printStackTrace();
						}
						
						String[] location = pointString.split(" ");
						Location l = new Location("dummyGPS");
						l.setLatitude(Double.parseDouble(location[0]));
						l.setLongitude(Double.parseDouble(location[1]));
						String magnitudeString = detail.split(" ")[1];
						int end = magnitudeString.length() - 1;
						double magnitude;
						magnitude = Double.parseDouble(magnitudeString.substring(0, end));
						detail = detail.split(",")[1].trim();
						Quake quake = new Quake(qDate, detail, l, magnitude, link);
						addNewQuake(quake);
					}
				}
			}
		}
		catch (MalformedURLException e) {
			e.printStackTrace();
		}
		catch (IOException e) {
			e.printStackTrace();
		}
		catch (ParserConfigurationException e) {
			e.printStackTrace();
		}
		catch (SAXException e) {
			e.printStackTrace();
		}
		finally
		{			
		}
	}
    
    private void addNewQuake(Quake _quake) {
		earthquakes.add(_quake);
		aa.notifyDataSetChanged();
	}
}